summaryrefslogtreecommitdiffstats
path: root/Src/StringTools.h
diff options
context:
space:
mode:
Diffstat (limited to 'Src/StringTools.h')
-rw-r--r--Src/StringTools.h34
1 files changed, 19 insertions, 15 deletions
diff --git a/Src/StringTools.h b/Src/StringTools.h
index 0c08805..d65772a 100644
--- a/Src/StringTools.h
+++ b/Src/StringTools.h
@@ -2,32 +2,36 @@
#define STRINGTOOLS_STRINGTOOLS_H
#include <string>
+#include <vector>
/* Handy utensils to manipulate strings */
class StringTools
{
public:
- //! Will replace every occurence of `find` in `str` by `subst`.
- static std::string Replace(const std::string& str, const char find, const std::string& subst);
+ //! Will replace every occurence of `find` in `str` by `subst`.
+ static std::string Replace(const std::string& str, const char find, const std::string& subst);
- //! Will replace every occurence of `find` in `str` by `subst`.
- static std::string Replace(const std::string& str, const std::string& find, const std::string& subst);
-
- //! Will replace every occurence of `find` in `str` by `subst`.
- static std::string Replace(const std::string& str, const char find, const char subst);
+ //! Will replace every occurence of `find` in `str` by `subst`.
+ static std::string Replace(const std::string& str, const std::string& find, const std::string& subst);
- //! Will replace every occurence of `find` in `str` by `subst`.
- static std::string Replace(const std::string& str, const std::string& find, const char subst);
+ //! Will replace every occurence of `find` in `str` by `subst`.
+ static std::string Replace(const std::string& str, const char find, const char subst);
- //! Will make a string all-lowercase.
- static std::string Lower(const std::string& str);
+ //! Will replace every occurence of `find` in `str` by `subst`.
+ static std::string Replace(const std::string& str, const std::string& find, const char subst);
- //! Will make a string all-uppercase.
- static std::string Upper(const std::string& str);
+ //! Will make a string all-lowercase.
+ static std::string Lower(const std::string& str);
+
+ //! Will make a string all-uppercase.
+ static std::string Upper(const std::string& str);
+
+ //! Will split a string by a string seperator
+ static std::vector<std::string> Split(const std::string& str, const std::string& seperator);
private:
- // No instanciation! >:(
- StringTools();
+ // No instanciation! >:(
+ StringTools();
};
#endif //STRINGTOOLS_STRINGTOOLS_H